@@ -1,26 +1,23 @@
-
 ##################################################################################
-#
-#    Copyright (C) 2006 Utah State University, All rights reserved.
-#
-#    This program is free software; you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
+#    Copyright (c) 2004-2009 Utah State University, All rights reserved. 
+#    Portions copyright 2009 Massachusetts Institute of Technology, All rights reserved.
+#                                                                                 
+#    This program is free software; you can redistribute it and/or modify         
+#    it under the terms of the GNU General Public License as published by         
+#    the Free Software Foundation, version 2.                                      
+#                                                                                 
+#    This program is distributed in the hope that it will be useful,              
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of               
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                
+#    GNU General Public License for more details.                                 
+#                                                                                 
+#    You should have received a copy of the GNU General Public License            
+#    along with this program; if not, write to the Free Software                  
+#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA    
+#                                                                                 
 ##################################################################################
 
 __author__  = '''Brent Lambert, David Ray, Jon Thomas'''
-__docformat__ = 'plaintext'
 __version__   = '$ Revision 0.0 $'[11:-2]
 
 from zope.formlib.form import  FormFields, action
@@ -31,8 +28,6 @@ from zope.app.form.browser.textwidgets import FileWidget
 from collective.zipfiletransport.utilities.interfaces import IZipFileTransportUtility
 from collective.zipfiletransport.browser.interfaces import IImport
 from collective.zipfiletransport import ZipFileTransportMessageFactory as _
-import string
-
 
 
 class ImportFormAdapter(object):
@@ -94,12 +89,15 @@ class ImportForm(EditForm):
     form_fields['filename'].custom_widget = FileWidget
 
     label = _(u'Import Content')
-    description = _(u"This form will import content from files contained in a .zip file, and will create new objects")
+    description = _(u"This form will import content from files contained in "
+                    u"a .zip file, and will create new objects")
 
     def __init__(self, context, request):
         self.context = context
         self.request = request
-        self.zft_util = getUtility(IZipFileTransportUtility)
+        self.zft_util = getUtility(
+                            IZipFileTransportUtility, 
+                            name="zipfiletransport")
 
     @action(_(u'Import'))
     def action_import(self, action, data):
@@ -110,7 +108,15 @@ class ImportForm(EditForm):
         excludefromnav = self.context.REQUEST.has_key('form.excludefromnav')
         categories = self.context.REQUEST['form.categories']
 
-        self.zft_util.importContent(file=file_obj, context=self.context, description=description, contributors=contributors, overwrite=overwrite, categories=categories, excludefromnav=excludefromnav )
+        self.zft_util.importContent(
+                                file=file_obj, 
+                                context=self.context, 
+                                description=description, 
+                                contributors=contributors, 
+                                overwrite=overwrite, 
+                                categories=categories, 
+                                excludefromnav=excludefromnav,
+                                )
         
         self.request.response.redirect('./folder_contents')
 
