@@ -1,6 +1,7 @@
 ##################################################################################
 #    Copyright (c) 2004-2009 Utah State University, All rights reserved. 
 #    Portions copyright 2009 Massachusetts Institute of Technology, All rights reserved.
+#    Portions copyright 2010 Cynapse India Pvt. Ltd.
 #                                                                                 
 #    This program is free software; you can redistribute it and/or modify         
 #    it under the terms of the GNU General Public License as published by         
@@ -25,7 +26,7 @@ from os import close
 from os.path import split, splitext
 from urllib import unquote
 
-from zope.component import queryUtility
+from zope.component import queryUtility, getAdapter
 from zope.interface import implements
 try:
     from zope.site.hooks import getSite
@@ -41,7 +42,8 @@ from Products.CMFCore.utils import getToolByName
 from plone.i18n.normalizer.interfaces import IURLNormalizer
 
 from zipfile import ZipFile, ZIP_DEFLATED
-from interfaces import IZipFileTransportUtility
+from interfaces import IZipFileTransportUtility, IZipFileAdapter
+
 
 class ZipFileTransportUtility(SimpleItem):
     """ ZipFileTransport Utility """
@@ -266,11 +268,11 @@ class ZipFileTransportUtility(SimpleItem):
     #               that will be included in the zip file.
     # filename - Refers to the fullpath filename of the exported zip file.
 
-    def exportContent(self, context, obj_paths=None, filename=None):
+    def exportContent(self, context, obj_paths=None, filename=None, comments=False):
         """ Export content to a zip file.
         """      
         objects_list = self._createObjectList(context, obj_paths)
-        zip_path = self._getAllObjectsData(context, objects_list)        
+        zip_path = self._getAllObjectsData(context, objects_list, comments)        
         return zip_path
 
     def _createObjectList(self, context, obj_paths=None, state=None):
@@ -305,7 +307,7 @@ class ZipFileTransportUtility(SimpleItem):
         file_name = unquote(file_name)
         return file_name
 
-    def _getAllObjectsData(self, context, objects_listing):
+    def _getAllObjectsData(self, context, objects_listing, comments):
         """ Returns the data in all files with a content object to be placed
             in a zipfile
         """
@@ -314,84 +316,22 @@ class ZipFileTransportUtility(SimpleItem):
         fd, path = tempfile.mkstemp('.zipfiletransport')
         close(fd)
         
-        zipFile =  ZipFile(path, 'w', ZIP_DEFLATED)
+        zipfile =  ZipFile(path, 'w', ZIP_DEFLATED)
         context_path = str(context.virtual_url_path())
 
+        pt = getToolByName(context, 'portal_properties')
+        mappings = pt.zipfile_properties.getProperty('content_mappings')
+        mappings = dict([x.split(':') for x in mappings])
+
         for obj in objects_listing:
-            object_extension = ''
-            object_path = str(obj.virtual_url_path())
-            
-            if self._objImplementsInterface(obj, interfaces.IATFile) or \
-                        self._objImplementsInterface(obj, interfaces.IATImage):
-                file_data = str(obj.data)
-                object_path = object_path.replace(context_path + '/', '')
-                
-            elif self._objImplementsInterface(obj, interfaces.IATDocument):
+            if obj.meta_type in mappings:
+                ob = getAdapter(obj, IZipFileAdapter, name=mappings[obj.meta_type])
+                ob.writeObjectToZipArchive(context, zipfile, comments)                
 
-                if "text/html" == obj.Format():
-                    file_data = obj.getText()
-                    object_extension = ".html"
-                        
-                elif "text/x-rst" == obj.Format():
-                    file_data = obj.getRawText() 
-                    object_extension = ".rst"                    
-
-                elif "text/structured" == obj.Format():
-                    file_data = obj.getRawText() 
-                    object_extension = ".stx"
-                        
-                elif "text/plain" == obj.Format():
-                    file_data = obj.getRawText() 
-                    object_extension = ".txt"
-
-                else:
-                    file_data = obj.getRawText()
-
-                object_path = object_path.replace(context_path + '/', '')
-
-            elif self._objImplementsInterface(obj,interfaces.IATFolder):
-                if hasattr(obj, 'getRawText'):
-                    file_data = obj.getRawText()
-
-                    if object_path == context_path:
-                        object_path = object_path.split("/")[-1]
-                    else:
-                        object_path = object_path.replace(context_path + '/', '')
-            
-                    if object_path[-5:] != ".html" and object_path[-4:] != ".htm":
-                        object_extension = ".html"
-            else:
-                continue
-
-            # start point for object path, adding 1 removes the initial '/'
-            object_path = self.generateSafeFileName(object_path)
-
-            if object_path: 
-                # reconstruct path with filename, restores non-ascii 
-                # characters in filenames
-                filename_path = []
-                for i in range(0, len(object_path.split('/'))):
-                    filename_path.append(obj.Title())
-                    obj = obj.aq_inner.aq_parent
-
-                if len(filename_path) > 1:
-                    filename_path.reverse()
-                    filename_path = '/'.join(filename_path)
-                else:
-                    filename_path = filename_path[0] 
-
-                # Add the correct file extension
-                if filename_path[-len(object_extension):] != object_extension:
-                    filename_path += object_extension
-
-                if 'Windows' in context.REQUEST['HTTP_USER_AGENT']:
-                    filename_path = filename_path.decode('utf-8').encode('cp437')
-                zipFile.writestr(filename_path, file_data)                
-
-        zipFile.close()
+        zipfile.close()
         return path
-                
-        
+
+
     def _objImplementsInterface(self, obj, interfaceClass):
         """ Return boolean indicating if obj implements the given interface.
         """
